@@ -81,9 +81,9 @@
  */
 
 #define VERSION		"2.5"			/* Version number... */
-#define VERS_DATE	"February 14, 2001"		/* for elm -v option */
+#define VERS_DATE	"August 7, 2001"		/* for elm -v option */
 #define WHAT_STRING	\
-	"@(#) Version 2.5, USENET supported version PL5"
+	"@(#) Version 2.5, USENET supported version PL6"
 
 #include <sys/types.h>	/* for fundamental types */
 #include <stdio.h>	/* Must get the _IOEOF flag for feof() on Convex */
@@ -405,7 +405,7 @@ struct header_rec {
 	long offset;		/** offset in bytes of message	**/
 	time_t received_time;	/** when elm received here	**/
 	char from[STRING];	/** who sent the message?	**/
-	char to[STRING];	/** who it was sent to		**/
+	char to[SLEN];	/** who it was sent to		**/
 	char messageid[STRING];	/** the Message-ID: value	**/
 	char time_zone[12];	/**                incl. tz	**/
 	time_t time_sent;	/** gmt when sent for sorting	**/
