@@ -527,7 +527,7 @@ int resyncing, quitting, prompt;
 	    unblock_signals();
 	    return(0);
 	  }
-	  if ((temp = fopen(temp_keep_file,"w")) == NULL) {
+	  if ((temp = file_open(temp_keep_file,"w")) == NULL) {
 	    dprint(1, (debugfile, "Error: could not create file %s [%s]\n", 
 	      temp_keep_file, strerror(errno)));
 	    ShutdownTerm();
