@@ -83,7 +83,7 @@ static int flock_fd,	/* file descriptor for flocking mailbox itself */
 static struct flock lock_info;
 #endif
 
-int
+static int
 Grab_the_file(flock_fd)
 int flock_fd;
 {
@@ -131,7 +131,7 @@ int flock_fd;
     return FLOCKING_OK;
 }
 
-int
+static int
 Release_the_file(flock_fd)
 int flock_fd;
 {
@@ -193,6 +193,7 @@ int direction;
 		   flock_iteration = 0;
       int kill_status;
       char pid_buffer[TLEN];
+      int grabrc;
 
 #ifdef	USE_DOTLOCK_LOCKING		/* { USE_DOTLOCK_LOCKING  */
       /* formulate lock file name */
@@ -259,10 +260,8 @@ int direction;
 	sleep(2);
       } while (create_iteration++ < MAX_ATTEMPTS);
       clear_error();
-      if (errno == ENOENT && create_fd >= 0)
-	errno = 0; /* Some os leave the errno from the open on the creat call */
-
-      if(errno != 0) {
+   
+      if(!(create_fd >= 0 || errno == ENOENT)) {
 	
 	/* we weren't able to create the lock file */
 
@@ -364,7 +363,7 @@ int direction;
       /* try to assert lock MAX_ATTEMPTS times */
       do {
 
-	switch (Grab_the_file (flock_fd)) {
+	switch ((grabrc = Grab_the_file (flock_fd))) {
 
 	case	FLOCKING_OK:
 	    goto    EXIT_RETRY_LOOP;
@@ -400,7 +399,7 @@ int direction;
 EXIT_RETRY_LOOP:
       clear_error();
 
-      if(errno != 0) {
+      if(grabrc != FLOCKING_OK) {
 	/* We couldn't lock the file. We die and leave not updating
 	 * the mailfile mbox or any of those! */
 	ShutdownTerm();
