@@ -312,7 +312,7 @@ int add_new_only;
 		curr_folder.tempname);
 	      leave(LEAVE_ERROR|LEAVE_KEEP_TEMPFOLDER);
 	    }
-	    if ((temp = fopen(curr_folder.tempname,"w")) == NULL) {
+	    if ((temp = file_open(curr_folder.tempname,"w")) == NULL) {
 	      ShutdownTerm();
 	      error2(catgets(elm_msg_cat, ElmSet, ElmCouldntOpenForTemp,
 		     "Cannot open \"%s\"! [%s]"),
