@@ -155,7 +155,9 @@ int number;
 		    (void) fclose (fpout);
  	            sprintf(Cmd, "metamail -p -z -m Elm %s", fname);
 		    Raw(OFF);
-                    ClearScreen();
+		    softkeys_off();
+		    EnableFkeys(OFF);
+		    ClearScreen();
 		    code = system_call(Cmd, SY_ENAB_SIGINT);
 		    Raw(ON | NO_TITE);	/* Raw on but don't switch screen */
 		    (void) unlink (fname);
@@ -166,6 +168,9 @@ int number;
 		      NewLine();
 		      Raw(OFF | NO_TITE); /* Raw off so raw on takes effect */
 		      Raw(ON); /* Finally raw on and switch screen */
+ 	              softkeys_on();
+		      EnableFkeys(ON);
+		       
 		      return(0);
 		    }
 		}
